<?php
namespace AkTest\Form\Annotation;

use Ak\Form\Annotation\AnnotationBuilder;
use AkTest\Form\AbstractTestCase;
use Laminas\Form\FieldsetInterface;

/**
 * Class AnnotationBuilderTest
 *
 * @package AkTest\Form\Annotation
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/wp-core
 */
final class AnnotationBuilderTest extends AbstractTestCase
{
    public function testIsRegistered()
    {
        $container = $this->getContainer();
        $this->assertContainerHasService($container, 'FormAnnotationBuilder', AnnotationBuilder::class);
    }

    public function testCanBuildNestedForms()
    {
        $builder = $this->getAnnotationBuilder();

        $form = $builder->createForm(ParentObject::class);
        $this->assertTrue($form->has('child'));

        /** @var FieldsetInterface $child */
        $child = $form->get('child');
        $this->assertInstanceOf(FieldsetInterface::class, $child);

        $this->assertTrue($child->has('name'));
        $this->assertTrue($child->has('value'));
    }

    public function testWillPassLabelToNestedForms()
    {
        $builder = $this->getAnnotationBuilder();

        $form = $builder->createForm(ParentObject::class);
        /** @var FieldsetInterface $child */
        $child = $form->get('child');

        $this->assertEquals('Child label', $child->getLabel());
    }
}
